/*
Nome: 9804_CDPTRGS_LOG_CDP_INSPETAPA.SQL

Descrio:
   Trigger para gravar o log das alteraes

Criao:
   17/02/2009 - Henrique Guidi Lobato

Descrio: A trigger insere registros na tabela LOGOPERA a partir das alteraes na tabela
              INSPETAPA, para verifio de erros
*/



IF EXISTS(SELECT *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE O.NAME = 'LOG_CDP_INSPETAPA' AND
                TYPE   = 'TR'                AND
                U.UID  = O.UID               AND
                U.NAME = USER)

DROP TRIGGER LOG_CDP_INSPETAPA
GO


CREATE TRIGGER LOG_CDP_INSPETAPA
ON INSPETAPA
FOR UPDATE,INSERT, DELETE
AS
BEGIN

   DECLARE @V_DSREMOTEADDR VARCHAR(15);
   DECLARE @V_DSREMOTEHOST VARCHAR(15);
   DECLARE @V_DSSERVERRDM  VARCHAR(20);
   DECLARE @V_DSSERVMETHOD VARCHAR(30);
   DECLARE @V_DSREMOTEOPER VARCHAR(12);
   DECLARE @V_DESC         VARCHAR(500);
   DECLARE @V_ITPESQ       VARCHAR(80);
   DECLARE @V_NMOPERADOR   VARCHAR(40);
   DECLARE @V_IDCLIEATIV   VARCHAR(1);
   DECLARE @V_NRINCREST    VARCHAR(40);
   DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/
   DECLARE @V_ID_TRIGGER       VARCHAR(1);

   DECLARE @V_CDFILIAL_OLD     VARCHAR(4);
   DECLARE @V_CDPRODUTO_OLD    VARCHAR(10);
   DECLARE @V_CDPROCFABRIC_OLD VARCHAR(10);
   DECLARE @V_CDETAPAPROD_OLD  VARCHAR(10);
   DECLARE @V_CDINSPECAO_OLD   VARCHAR(10);
   DECLARE @V_NRINSPETAPA_OLD  VARCHAR(3);
   DECLARE @V_CDEQUIPPRO_OLD   VARCHAR(10);
   DECLARE @V_CDSETOR_OLD      VARCHAR(4);
   DECLARE @V_QTHRINSPEXE_OLD  double precision;
   DECLARE @V_NRORDINSETAP_OLD VARCHAR(3);
   DECLARE @V_IDPROCINSET_OLD  VARCHAR(1);
   DECLARE @V_NRORDIMPINS_OLD  VARCHAR(3);

   DECLARE @V_CDFILIAL_NEW     VARCHAR(4);
   DECLARE @V_CDPRODUTO_NEW    VARCHAR(10);
   DECLARE @V_CDPROCFABRIC_NEW VARCHAR(10);
   DECLARE @V_CDETAPAPROD_NEW  VARCHAR(10);
   DECLARE @V_CDINSPECAO_NEW   VARCHAR(10);
   DECLARE @V_NRINSPETAPA_NEW  VARCHAR(3);
   DECLARE @V_CDEQUIPPRO_NEW   VARCHAR(10);
   DECLARE @V_CDSETOR_NEW      VARCHAR(4);
   DECLARE @V_QTHRINSPEXE_NEW  double precision;
   DECLARE @V_NRORDINSETAP_NEW VARCHAR(3);
   DECLARE @V_IDPROCINSET_NEW  VARCHAR(1);
   DECLARE @V_NRORDIMPINS_NEW  VARCHAR(3);

/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDCLIEATIV = '';
   SET @V_NRINCREST  = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO  @V_NMOPERADOR;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVERRDM,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER;

   DECLARE C_CURSOR CURSOR FOR
      SELECT
         'D' IDCOMANDO,
         CDFILIAL,
         CDPRODUTO,
         CDPROCFABRIC,
         CDETAPAPROD,
         CDINSPECAO,
         NRINSPETAPA,
         CDEQUIPPRO,
         CDSETOR,
         QTHRINSPEXE,
         NRORDINSETAP,
         IDPROCINSET,
         NRORDIMPINS,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL

      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)
      UNION ALL

      SELECT
         'U' IDCOMANDO,
         DELETED.CDFILIAL,
         DELETED.CDPRODUTO,
         DELETED.CDPROCFABRIC,
         DELETED.CDETAPAPROD,
         DELETED.CDINSPECAO,
         DELETED.NRINSPETAPA,
         DELETED.CDEQUIPPRO,
         DELETED.CDSETOR,
         DELETED.QTHRINSPEXE,
         DELETED.NRORDINSETAP,
         DELETED.IDPROCINSET,
         DELETED.NRORDIMPINS,
         INSERTED.CDFILIAL,
         INSERTED.CDPRODUTO,
         INSERTED.CDPROCFABRIC,
         INSERTED.CDETAPAPROD,
         INSERTED.CDINSPECAO,
         INSERTED.NRINSPETAPA,
         INSERTED.CDEQUIPPRO,
         INSERTED.CDSETOR,
         INSERTED.QTHRINSPEXE,
         INSERTED.NRORDINSETAP,
         INSERTED.IDPROCINSET,
         INSERTED.NRORDIMPINS

      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDPRODUTO  = DELETED.CDPRODUTO

      UNION ALL

      SELECT
        'I' IDCOMANDO,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
	CDFILIAL,     
	CDPRODUTO,    
	CDPROCFABRIC, 
	CDETAPAPROD,  
	CDINSPECAO,   
	NRINSPETAPA,  
	CDEQUIPPRO,   
	CDSETOR,      
	QTHRINSPEXE,  
	NRORDINSETAP, 
	IDPROCINSET,  
	NRORDIMPINS  

     FROM
        INSERTED
     WHERE
        0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,
                                
				 @V_CDFILIAL_OLD,    
				 @V_CDPRODUTO_OLD,   
				 @V_CDPROCFABRIC_OLD,
				 @V_CDETAPAPROD_OLD, 
				 @V_CDINSPECAO_OLD,  
				 @V_NRINSPETAPA_OLD, 
				 @V_CDEQUIPPRO_OLD,  
				 @V_CDSETOR_OLD,     
				 @V_QTHRINSPEXE_OLD, 
				 @V_NRORDINSETAP_OLD,
				 @V_IDPROCINSET_OLD, 
				 @V_NRORDIMPINS_OLD, 

				 @V_CDFILIAL_NEW,    
				 @V_CDPRODUTO_NEW,   
				 @V_CDPROCFABRIC_NEW,
				 @V_CDETAPAPROD_NEW,
				 @V_CDINSPECAO_NEW,
			         @V_NRINSPETAPA_NEW,
				 @V_CDEQUIPPRO_NEW,
				 @V_CDSETOR_NEW,
				 @V_QTHRINSPEXE_NEW,
				 @V_NRORDINSETAP_NEW,
				 @V_IDPROCINSET_NEW,
				 @V_NRORDIMPINS_NEW;


   WHILE (@@FETCH_STATUS = 0) BEGIN

    IF @V_ID_TRIGGER = 'I' BEGIN

           IF @V_CDFILIAL_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'Filial= ' + ISNULL(@V_CDFILIAL_NEW,'') + ' ';
           END;

           IF @V_CDPRODUTO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF @V_CDPROCFABRIC_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProcFabric= ' + ISNULL(@V_CDPROCFABRIC_NEW,'') + ' ';
           END;

           IF @V_CDETAPAPROD_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEtapaProd= ' + ISNULL(@V_CDETAPAPROD_NEW,'') + ' ';
           END;

           IF @V_CDINSPECAO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdInspecao= ' + ISNULL(@V_CDINSPECAO_NEW,'') + ' ';
           END;

           IF @V_NRINSPETAPA_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrInspeTapa= ' + ISNULL(@V_NRINSPETAPA_NEW,'') + ' ';
           END;

           IF @V_CDEQUIPPRO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEquiPro= ' + @V_CDEQUIPPRO_NEW + ' ';
           END;

           IF @V_CDSETOR_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdSetor= ' + @V_CDSETOR_NEW + ' ';
           END;

           IF @V_QTHRINSPEXE_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'QtHrInspExe= ' + RTRIM(CONVERT(CHAR, @V_QTHRINSPEXE_NEW)) + ' ';
           END;

           IF @V_NRORDINSETAP_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdInsEtap= ' + @V_NRORDINSETAP_NEW + ' ';
           END;

           IF @V_IDPROCINSET_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdProcInsEt= ' + @V_IDPROCINSET_NEW + ' ';
           END;

           IF @V_NRORDIMPINS_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdImpIns= ' + @V_NRORDIMPINS_NEW + ' ';
           END;

           SET @V_ITPESQ = @V_CDFILIAL_NEW   + @V_CDPRODUTO_NEW   + @V_CDPROCFABRIC_NEW + @V_CDETAPAPROD_NEW +
                           @V_CDINSPECAO_NEW + @V_NRINSPETAPA_NEW;

         SET @V_IDTIPOOPER = '1';
     END
     ELSE BEGIN
        IF @V_ID_TRIGGER = 'U' BEGIN

           IF (@V_CDFILIAL_OLD <> @V_CDFILIAL_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'Filial= ' + ISNULL(@V_CDFILIAL_NEW,'') + ' ';
           END;

           IF (@V_CDPRODUTO_OLD <> @V_CDPRODUTO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF (@V_CDPROCFABRIC_OLD <> @V_CDPROCFABRIC_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdProcFabric= ' + ISNULL(@V_CDPROCFABRIC_NEW,'') + ' ';
           END;

           IF (@V_CDETAPAPROD_OLD <> @V_CDETAPAPROD_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdEtapaProd= ' + ISNULL(@V_CDETAPAPROD_NEW,'') + ' ';
           END;

           IF (@V_CDINSPECAO_OLD <> @V_CDINSPECAO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdInspecao= ' + ISNULL(@V_CDINSPECAO_NEW,'') + ' ';
           END;

           IF (@V_NRINSPETAPA_OLD <> @V_NRINSPETAPA_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'NrInspeTapa= ' + ISNULL(@V_NRINSPETAPA_NEW,'') + ' ';
           END;

           IF (@V_CDEQUIPPRO_OLD <> @V_CDEQUIPPRO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdEquiPro= ' + @V_CDEQUIPPRO_NEW + ' ';
           END;

           IF (ISNULL(@V_CDSETOR_OLD,'-1') <> ISNULL(@V_CDSETOR_NEW,'-1')) BEGIN
              SET @V_DESC = @V_DESC + 'CdSetor= ' + @V_CDSETOR_NEW + ' ';
           END;	

           IF (ISNULL(@V_QTHRINSPEXE_OLD,'-1') <> ISNULL(@V_QTHRINSPEXE_NEW,'-1')) BEGIN
              SET @V_DESC = @V_DESC + 'QtHrInspExe= ' + RTRIM(CONVERT(CHAR, @V_QTHRINSPEXE_NEW)) + ' ';
           END;

           IF (@V_NRORDINSETAP_OLD <> @V_NRORDINSETAP_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdInsEtap= ' + @V_NRORDINSETAP_NEW + ' ';
           END;

           IF (ISNULL(@V_IDPROCINSET_OLD,'-1') <> ISNULL(@V_IDPROCINSET_NEW,'-1')) BEGIN
              SET @V_DESC = @V_DESC + 'IdProcInsEt= ' + @V_IDPROCINSET_NEW + ' ';
           END;

           IF (@V_NRORDIMPINS_OLD <> @V_NRORDIMPINS_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdImpIns= ' + @V_NRORDIMPINS_NEW + ' ';
           END;

           SET @V_ITPESQ = @V_CDFILIAL_NEW   + @V_CDPRODUTO_NEW   + @V_CDPROCFABRIC_NEW + @V_CDETAPAPROD_NEW +
                           @V_CDINSPECAO_NEW + @V_NRINSPETAPA_NEW;

           SET @V_IDTIPOOPER = '2';

        END;

        IF @V_ID_TRIGGER = 'D'  BEGIN

           IF @V_CDFILIAL_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'Filial= ' + ISNULL(@V_CDFILIAL_OLD,'') + ' ';
           END;

           IF @V_CDPRODUTO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_OLD,'') + ' ';
           END;

           IF @V_CDPROCFABRIC_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProcFabric= ' + ISNULL(@V_CDPROCFABRIC_OLD,'') + ' ';
           END;

           IF @V_CDETAPAPROD_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEtapaProd= ' + ISNULL(@V_CDETAPAPROD_OLD,'') + ' ';
           END;

           IF @V_CDINSPECAO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdInspecao= ' + ISNULL(@V_CDINSPECAO_OLD,'') + ' ';
           END;

           IF @V_NRINSPETAPA_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrInspeTapa= ' + ISNULL(@V_NRINSPETAPA_OLD,'') + ' ';
           END;

           IF @V_CDEQUIPPRO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEquiPro= ' + @V_CDEQUIPPRO_OLD + ' ';
           END;

           IF @V_CDSETOR_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdSetor= ' + @V_CDSETOR_OLD + ' ';
           END;

           IF @V_QTHRINSPEXE_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'QtHrInspExe= ' + RTRIM(CONVERT(CHAR, @V_QTHRINSPEXE_OLD)) + ' ';
           END;

           IF @V_NRORDINSETAP_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdInsEtap= ' + @V_NRORDINSETAP_OLD + ' ';
           END;

           IF @V_IDPROCINSET_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdProcInsEt= ' + @V_IDPROCINSET_OLD + ' ';
           END;

           IF @V_NRORDIMPINS_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrOrdImpIns= ' + @V_NRORDIMPINS_OLD + ' ';
           END;
                  
           SET @V_ITPESQ = @V_CDFILIAL_OLD   + @V_CDPRODUTO_OLD   + @V_CDPROCFABRIC_OLD + @V_CDETAPAPROD_OLD + 
                           @V_CDINSPECAO_OLD + @V_NRINSPETAPA_OLD;

           SET @V_IDTIPOOPER = '3';
        END;
     END;

     IF NOT (@V_DESC IS NULL) BEGIN

        INSERT INTO LOGOPERA ( NMTABELA, DTOPERACAO, NMRESPOPER,
                               IDTIPOOPER,   DSOPERACAO, CDPESQITEM,
                               DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER,
                               DSMETUSUOPER, CDORESPOPER)
                    VALUES   ('INSPETAPA', GETDATE() ,    ISNULL(@V_NMOPERADOR,' '),
                               @V_IDTIPOOPER,   @V_DESC, @V_ITPESQ,
                               @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST,
                               @V_DSSERVMETHOD,   @V_DSREMOTEOPER);
     END;

   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,

				 @V_CDFILIAL_OLD,    
				 @V_CDPRODUTO_OLD,   
				 @V_CDPROCFABRIC_OLD,
				 @V_CDETAPAPROD_OLD, 
				 @V_CDINSPECAO_OLD,  
				 @V_NRINSPETAPA_OLD, 
				 @V_CDEQUIPPRO_OLD,  
				 @V_CDSETOR_OLD,     
				 @V_QTHRINSPEXE_OLD, 
				 @V_NRORDINSETAP_OLD,
				 @V_IDPROCINSET_OLD, 
				 @V_NRORDIMPINS_OLD, 

				 @V_CDFILIAL_NEW,    
				 @V_CDPRODUTO_NEW,   
				 @V_CDPROCFABRIC_NEW,
				 @V_CDETAPAPROD_NEW, 
				 @V_CDINSPECAO_NEW,  
			         @V_NRINSPETAPA_NEW, 
				 @V_CDEQUIPPRO_NEW,  
				 @V_CDSETOR_NEW,     
				 @V_QTHRINSPEXE_NEW, 
				 @V_NRORDINSETAP_NEW,
				 @V_IDPROCINSET_NEW, 
				 @V_NRORDIMPINS_NEW; 

   END;

   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_CDP_INSPETAPA','5.07.000';
GO
